# Generated by Django 5.1.3 on 2026-02-05 15:21

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("uk_geo_utils", "0013_rename_bua24_onspd_bua24cd_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="onspd",
            name="bua24cd",
            field=models.CharField(
                blank=True, help_text="Built-up Area (BUA)", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="cal24cd",
            field=models.CharField(
                blank=True, help_text="Cancer Alliance (CAL)", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="educ23cd",
            field=models.CharField(
                blank=True,
                help_text="Local Learning and Skills Council (LLSC)/ Dept. of Children, Education, Lifelong Learning and Skills (DCELLS)/ Enterprise Region (ER)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="icb23cd",
            field=models.CharField(
                blank=True,
                help_text="Integrated Care Board (ICB)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="imd20ind",
            field=models.CharField(
                blank=True,
                help_text="Index of Multiple Deprivation (IMD)for 2011 LSOAs",
                max_length=5,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="itl25cd",
            field=models.CharField(
                blank=True,
                help_text="International Territorial Level (former NUTS)",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lat",
            field=models.CharField(
                blank=True, help_text="Decimal degrees latitude", max_length=10
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lep21cd1",
            field=models.CharField(
                blank=True,
                help_text="Local Enterprise Partnership (LEP) - first instance",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lep21cd2",
            field=models.CharField(
                blank=True,
                help_text="Local Enterprise Partnership (LEP) - second instance",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="long",
            field=models.CharField(
                blank=True, help_text="Decimal degrees longitude", max_length=10
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lsoa01cd",
            field=models.CharField(
                blank=True,
                help_text="2001 Census Lower Layer Super Output Area (LSOA)/ Data Zone (DZ)/ Super Output Area (SOA)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lsoa11cd",
            field=models.CharField(
                blank=True,
                help_text="2011 Census Lower Layer Super Output Area (LSOA)/ Data Zone (DZ)/ SOA",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lsoa21cd",
            field=models.CharField(
                blank=True,
                help_text="2021 Census Lower Layer Super Output Area (LSOA)/Super Data Zone (SDZ)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="msoa01cd",
            field=models.CharField(
                blank=True,
                help_text="2001 Census Middle Layer Super Output Area (MSOA)/ Intermediate Zone (IZ)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="msoa11cd",
            field=models.CharField(
                blank=True,
                help_text="2011 Census Middle Layer Super Output Area (MSOA)/Intermediate Zone (IZ)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="msoa21cd",
            field=models.CharField(
                blank=True,
                help_text="2021 Census Middle Layer Super Output Area (MSOA)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="npark16cd",
            field=models.CharField(
                blank=True, help_text="National park", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="oa01cd",
            field=models.CharField(
                blank=True,
                help_text="2001 Census Output Area (OA)",
                max_length=10,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="oa11cd",
            field=models.CharField(
                blank=True,
                help_text="2011 Census Output Area (OA)/Small Area (SA)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="oa21cd",
            field=models.CharField(
                blank=True,
                help_text="2021 Census Output Area (OA)/Data Zone (DZ)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="oac01ind",
            field=models.CharField(
                blank=True,
                help_text=" 2001 Census Output Area classification (OAC)",
                max_length=3,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="oac11ind",
            field=models.CharField(
                blank=True,
                help_text="2011 Census Output Area classification (OAC)",
                max_length=3,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="pco19cd",
            field=models.CharField(
                blank=True,
                help_text="Primary Care Organisatioin (PCO): Care Trust (PCT)/ Care Trust/ Care Trust Plus (CT)/ Local Health Board (LHB)/ Community Health Partnership (CHP)/ Local Commissioning Group (LCG)/ Primary Healthcare Directorate (PHD)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="pfa23cd",
            field=models.CharField(
                blank=True, help_text="Police Force Area (PFA)", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="ruc01ind",
            field=models.CharField(
                blank=True,
                help_text="2001 Census urban/rural indicator",
                max_length=1,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="ruc11ind",
            field=models.CharField(
                blank=True,
                help_text="2011 Census rural-urban classification",
                max_length=2,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="ruc21ind",
            field=models.CharField(
                blank=True,
                help_text="2021 Census rural-urban classification",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="sicbl24cd",
            field=models.CharField(
                blank=True,
                help_text="Sub ICB Location (LOC)/ Local Health Board (LHB)/ Community Health Partnership (CHP)/ Local Commissioning Group (LCG)/ Primary Healthcare Directorate (PHD)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="ssr95cd",
            field=models.CharField(
                blank=True,
                help_text="Standard Statistical Region (SSR)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="wdcas03cd",
            field=models.CharField(
                blank=True,
                help_text="Census Area Statistics (CAS) ward",
                max_length=6,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="wdstl05cd",
            field=models.CharField(
                blank=True,
                help_text="2005 ‘statistical’ ward (England and Wales only)",
                max_length=6,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="wz11cd",
            field=models.CharField(
                blank=True,
                help_text="2011 Census Workplace Zone (WZ)",
                max_length=9,
            ),
        ),
    ]
