# Generated by Django 5.1.3 on 2026-02-05 15:19

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "uk_geo_utils",
            "0012_rename_ced_onspd_ced25cd_rename_ctry_onspd_ctry25cd_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="onspd",
            old_name="bua24",
            new_name="bua24cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="calncv",
            new_name="cal24cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="teclec",
            new_name="educ23cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="icb",
            new_name="icb23cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="imd",
            new_name="imd20ind",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="itl",
            new_name="itl25cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="lep1",
            new_name="lep21cd1",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="lep2",
            new_name="lep21cd2",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="lsoa01",
            new_name="lsoa01cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="lsoa11",
            new_name="lsoa11cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="lsoa21",
            new_name="lsoa21cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="msoa01",
            new_name="msoa01cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="msoa11",
            new_name="msoa11cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="msoa21",
            new_name="msoa21cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="npark",
            new_name="npark16cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oa01",
            new_name="oa01cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oa11",
            new_name="oa11cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oa21",
            new_name="oa21cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oac01",
            new_name="oac01ind",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oac11",
            new_name="oac11ind",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="pct",
            new_name="pco19cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="pfa",
            new_name="pfa23cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="ur01ind",
            new_name="ruc01ind",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="ru11ind",
            new_name="ruc11ind",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="sicbl",
            new_name="sicbl24cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="casward",
            new_name="wdcas03cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="statsward",
            new_name="wdstl05cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="wz11",
            new_name="wz11cd",
        ),
        migrations.RemoveField(
            model_name="onspd",
            name="streg",
        ),
        migrations.AddField(
            model_name="onspd",
            name="ruc21ind",
            field=models.CharField(blank=True, max_length=4),
        ),
        migrations.AddField(
            model_name="onspd",
            name="ssr95cd",
            field=models.CharField(blank=True, max_length=9),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="ced25cd",
            field=models.CharField(
                blank=True, help_text="County Electoral Division", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="ctry25cd",
            field=models.CharField(
                blank=True, help_text="Country", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="cty25cd",
            field=models.CharField(
                blank=True, help_text="County", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="dointr",
            field=models.CharField(
                blank=True, help_text="Date of introduction", max_length=6
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="doterm",
            field=models.CharField(
                blank=True, help_text="Date of termination", max_length=6
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="east1m",
            field=models.CharField(
                blank=True,
                help_text="National grid reference - Easting",
                max_length=6,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="eer20cd",
            field=models.CharField(
                blank=True, help_text="European Electoral Region", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="gridind",
            field=models.CharField(
                blank=True,
                help_text="Grid reference positional quality indicator",
                max_length=1,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="hlth19cd",
            field=models.CharField(
                blank=True,
                help_text="Former Strategic Health Authority (SHA)/ Local Health Board (LHB)/ Health Board (HB)/ Health Authority (HA)/ Health & Social Care Board (HSCB)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lad25cd",
            field=models.CharField(
                blank=True,
                help_text="Local authority; district (LAD): unitary authority (UA)/non- metroploitan district (NMD)/ metropolitan district (MD)/ London borough (LB)/ council area (CA)/district council area (DCA)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="nhser24cd",
            field=models.CharField(
                blank=True,
                help_text="NHS England (Region) (NHS ER)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="north1m",
            field=models.CharField(
                blank=True,
                help_text="National grid reference - Northing",
                max_length=7,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="parncp25cd",
            field=models.CharField(
                blank=True,
                help_text="Civil parish/non- civil parish/ community",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="pcd7",
            field=models.CharField(
                blank=True,
                help_text="Unit postcode – 7 character version",
                max_length=7,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="pcd8",
            field=models.CharField(
                blank=True,
                help_text="Unit postcode – 8 character version",
                max_length=8,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="pcds",
            field=models.CharField(
                blank=True,
                help_text="Unit postcode - variable length (e-Gif) version",
                max_length=8,
                primary_key=True,
                serialize=False,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="pcon24cd",
            field=models.CharField(
                blank=True,
                help_text="Westminster parliamentary constituency",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="rgn25cd",
            field=models.CharField(
                blank=True, help_text="Region (former GOR)", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="ttwa15cd",
            field=models.CharField(
                blank=True, help_text="Travel to Work Area (TTWA)", max_length=9
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="usrtypind",
            field=models.CharField(
                blank=True, help_text="Postcode user type", max_length=1
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="wd25cd",
            field=models.CharField(
                blank=True, help_text="(Electoral) ward/division", max_length=9
            ),
        ),
    ]
