# Generated by Django 5.1 on 2025-02-26 15:19

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "uk_geo_utils",
            "0010_rename_bua11_onspd_bua22_rename_nuts_onspd_itl_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="onspd",
            old_name="bua22",
            new_name="bua24",
        ),
    ]
