# Generated by Django 5.1.3 on 2026-02-05 14:44

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("uk_geo_utils", "0011_rename_bua22_onspd_bua24"),
    ]

    operations = [
        migrations.RenameField(
            model_name="onspd",
            old_name="ced",
            new_name="ced25cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="ctry",
            new_name="ctry25cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oscty",
            new_name="cty25cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oseast1m",
            new_name="east1m",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="eer",
            new_name="eer20cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="osgrdind",
            new_name="gridind",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oshlthau",
            new_name="hlth19cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="oslaua",
            new_name="lad25cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="nhser",
            new_name="nhser24cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="osnrth1m",
            new_name="north1m",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="parish",
            new_name="parncp25cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="pcd",
            new_name="pcd7",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="pcd2",
            new_name="pcd8",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="pcon",
            new_name="pcon24cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="rgn",
            new_name="rgn25cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="ttwa",
            new_name="ttwa15cd",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="usertype",
            new_name="usrtypind",
        ),
        migrations.RenameField(
            model_name="onspd",
            old_name="osward",
            new_name="wd25cd",
        ),
    ]
