# Generated by Django 5.1.3 on 2026-03-04 15:32

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "uk_geo_utils",
            "0014_alter_onspd_bua24cd_alter_onspd_cal24cd_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="onspd",
            name="educ23cd",
            field=models.CharField(
                blank=True,
                help_text="Local Learning and Skills Council (LLSC)/Dept. of Children, Education, Lifelong Learning and Skills (DCELLS)/Enterprise Region (ER)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="hlth19cd",
            field=models.CharField(
                blank=True,
                help_text="Former Strategic Health Authority (SHA)/Local Health Board (LHB)/Health Board (HB)/Health Authority (HA)/Health & Social Care Board (HSCB)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lad25cd",
            field=models.CharField(
                blank=True,
                help_text="Local authority district (LAD): unitary authority (UA)/non- metroploitan district (NMD)/metropolitan district (MD)/London borough (LB)/council area (CA)/district council area (DCA)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lsoa01cd",
            field=models.CharField(
                blank=True,
                help_text="2001 Census Lower Layer Super Output Area (LSOA)/Data Zone (DZ)/Super Output Area (SOA)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="lsoa11cd",
            field=models.CharField(
                blank=True,
                help_text="2011 Census Lower Layer Super Output Area (LSOA)/Data Zone (DZ)/SOA",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="msoa01cd",
            field=models.CharField(
                blank=True,
                help_text="2001 Census Middle Layer Super Output Area (MSOA)/Intermediate Zone (IZ)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="parncp25cd",
            field=models.CharField(
                blank=True,
                help_text="Civil parish/non-civil parish/community",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="pco19cd",
            field=models.CharField(
                blank=True,
                help_text="Primary Care Organisatioin (PCO): Care Trust (PCT)/Care Trust/Care Trust Plus (CT)/Local Health Board (LHB)/Community Health Partnership (CHP)/Local Commissioning Group (LCG)/Primary Healthcare Directorate (PHD)",
                max_length=9,
            ),
        ),
        migrations.AlterField(
            model_name="onspd",
            name="sicbl24cd",
            field=models.CharField(
                blank=True,
                help_text="Sub ICB Location (LOC)/Local Health Board (LHB)/Community Health Partnership (CHP)/Local Commissioning Group (LCG)/Primary Healthcare Directorate (PHD)",
                max_length=9,
            ),
        ),
    ]
